=======
History
=======

1.0.0 (2021-09-16)
------------------

* Disabled creation of SKiDL logging and ERC files.
* Decided this tool was mature to the point it could be called 1.0.0.


0.4.0 (2020-09-20)
------------------

* Fixed infinite recursion caused by search that returns an entire list of invalid footprints (issue #2).


0.3.0 (2020-06-07)
------------------

* Fixed copy-paste part/footprint errors caused by clipboard already being open.


0.2.0 (2020-04-28)
------------------

* Replaced sorting function deleted from SKiDL.
* Updated some Grid definitions for wxpython 4.0.


0.1.0 (2019-12-17)
------------------

* Extracted zyc utility from SKiDL repo and released separately on PyPi.
